@@ -57,10 +57,12 @@ impl Colour {
     }
 
     #[inline(always)]
+    #[allow(dead_code)]
     fn f32_to_hex_u32(val: f32, shift: u8) -> u32 {
         ((val * 255.0).round() as u32) << shift
     }
 
+    #[allow(dead_code)]
     fn clamp_u8_to_f32(val: u8) -> f32 {
         if val >= 255 {
             1.0
@@ -71,6 +73,7 @@ impl Colour {
         }
     }
 
+    #[allow(dead_code)]
     fn f32_to_rgba_u8(val: f32) -> u8 {
         if val >= 1.0 {
             255
@@ -345,7 +348,7 @@ mod red_xx {
     use super::*;
 
     #[test]
-    pub fn it_should_return_red_given() {
+    fn it_should_return_red_given() {
         let rgba_hex = 0xffa89321;
         let colour = Colour::new_from_rgba(rgba_hex);
 
@@ -360,7 +363,7 @@ mod green_xx {
     use super::*;
 
     #[test]
-    pub fn it_should_return_green_given() {
+    fn it_should_return_green_given() {
         let rgba_hex = 0xffa89321;
         let colour = Colour::new_from_rgba(rgba_hex);
 
@@ -375,7 +378,7 @@ mod blue_xx {
     use super::*;
 
     #[test]
-    pub fn it_should_return_blue_given() {
+    fn it_should_return_blue_given() {
         let rgba_hex = 0xffa89321;
         let colour = Colour::new_from_rgba(rgba_hex);
 
@@ -390,7 +393,7 @@ mod alpha_xx {
     use super::*;
 
     #[test]
-    pub fn it_should_return_alpha_given() {
+    fn it_should_return_alpha_given() {
         let rgba_hex = 0xffa89321;
         let colour = Colour::new_from_rgba(rgba_hex);
 
@@ -405,7 +408,7 @@ mod new_rgba_hex {
     use super::*;
 
     #[test]
-    pub fn it_should_have_components_match_those_given() {
+    fn it_should_have_components_match_those_given() {
         let rgba_hex = 0xffa89321;
         let colour = Colour::new_from_rgba(rgba_hex);
 
@@ -422,7 +425,7 @@ mod replace_alpha_f32 {
     use super::*;
 
     #[test]
-    pub fn it_should_replace_alpha_value() {
+    fn it_should_replace_alpha_value() {
         let rgba_hex = 0xffffff11;
         let mut colour = Colour::new_from_rgba(rgba_hex);
 
@@ -437,7 +440,7 @@ mod replace_alpha_f32 {
     }
 
     #[test]
-    pub fn it_should_not_replace_other_values() {
+    fn it_should_not_replace_other_values() {
         let rgba_hex = 0xffffff11;
         let mut colour = Colour::new_from_rgba(rgba_hex);
 
