@@ -21,6 +21,7 @@ use crate::num::Num;
 use crate::num::ToRounded;
 use crate::num::ToSignedClamped;
 
+use crate::geom::Circle;
 use crate::geom::Point;
 use crate::geom::Rect;
 use crate::geom::Size;
@@ -88,7 +89,7 @@ impl<N: Num> Line<N> {
 
     /// Where `n` is a valid from 0.0 to 1.0,
     /// this will return a point on the length of the line.
-    pub fn transition_point(self, n: N) -> Point<N> {
+    pub fn interpolation_point(self, n: N) -> Point<N> {
         self.start() + self.diff_as_point() * n
     }
 
@@ -133,6 +134,10 @@ impl<N: Num> Line<N> {
         self.intersect_line(other).is_some()
     }
 
+    pub fn overlaps_circle(self, other: Circle<N>) -> bool {
+        other.overlaps_line(self)
+    }
+
     pub fn intersect_line(self, other: Line<N>) -> Option<Point<N>> {
         let self_rounded = self.to_rounded();
         let other_rounded = other.to_rounded();
@@ -312,6 +317,12 @@ impl<N: Num> Line<N> {
     pub(crate) fn to_f32(self) -> Line<f32> {
         self.to_rounded()
     }
+
+    /// Returns a line where the start is at the end,
+    /// and the end is at the start.
+    pub fn flip(self) -> Self {
+        Self(self.end(), self.start())
+    }
 }
 
 impl<N: Num + Signed> Line<N> {
@@ -851,25 +862,25 @@ mod intersect {
 }
 
 #[cfg(test)]
-mod transition_point {
+mod interpolation_point {
     use super::*;
 
     #[test]
     fn it_should_return_start_when_zero() {
         let line = Line(Point(3.0, 4.0), Point(14.0, 19.0));
-        assert_eq!(line.transition_point(0.0), Point(3.0, 4.0));
+        assert_eq!(line.interpolation_point(0.0), Point(3.0, 4.0));
     }
 
     #[test]
     fn it_should_return_end_when_one() {
         let line = Line(Point(3.0, 4.0), Point(14.0, 19.0));
-        assert_eq!(line.transition_point(1.0), Point(14.0, 19.0));
+        assert_eq!(line.interpolation_point(1.0), Point(14.0, 19.0));
     }
 
     #[test]
     fn it_should_return_middle_when_half() {
         let line = Line(Point(3.0, 4.0), Point(14.0, 19.0));
-        assert_eq!(line.transition_point(0.5), Point(8.5, 11.5));
+        assert_eq!(line.interpolation_point(0.5), Point(8.5, 11.5));
     }
 }
 
@@ -1031,3 +1042,14 @@ mod intersect_line {
         assert_eq!(intersection, None);
     }
 }
+
+#[cfg(test)]
+mod flip {
+    use super::*;
+
+    #[test]
+    fn it_should_swap_start_and_end() {
+        let line: Line<i32> = Line(Point(123, 456), Point(987, 654));
+        assert_eq!(line.flip(), Line(Point(987, 654), Point(123, 456)))
+    }
+}
